@@ -10,21 +10,24 @@ def compile_c_code(abs_dirpath):
 	from os import chdir
 
 	chdir(abs_dirpath)
+	print('•naked• Compiling the C source library files...')
 	run("python setup.py build_ext --inplace")
 
 def help():
 	from Naked.toolshed.system import exit_success
 	help_string = """
 Naked build Command Help
-------------------------
+========================
 The build command compiles the Naked C libraries.  This requires an installed C compiler.
 
 USAGE
   naked build
 
-OPTIONS
+SECONDARY COMMANDS
   none
-	"""
+
+OPTIONS
+  none"""
 	print(help_string)
 	exit_success()
 
