@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+import sys
 from functools import wraps
+from Naked.commandline import Command
 
 def print_scratch(func):
     @wraps(func)
@@ -20,14 +22,9 @@ def run_scratchpad():
     # test3 = "Hey! It's Bengali ব য,and here is some more ২"
     # print(unicode(test2))
 
-    from Naked.toolshed.network import HTTP
-
-    http = HTTP('bogus.com')
-    if http.get():
-        status = http.res.status_code
-    else:
-        fail_status = http.res.status_code
-
+    import subprocess
+    arguments = 'naked build'
+    return_code = subprocess.call(arguments, stdin=None, stdout=sys.stdout, stderr=None, shell=True)
 
 
 if __name__ == '__main__':
